@@ -22,6 +22,7 @@
 #include <enums.h>
 #include <fcntl.h>
 #include <globals.h>
+#include <gtk/gtk.h>
 #include <init.h>
 #include <math.h>
 #include <input.h>
@@ -60,6 +61,8 @@ extern gfloat right_amplitude;
 extern GtkObject *lf_adj;
 extern GtkObject *hf_adj;
 extern GtkObject *lag_adj;
+PangoLayout *layout = NULL;
+PangoFontDescription *font_desc = NULL;
 
 void init()
 {
@@ -74,14 +77,18 @@ void init()
            default file is missing or incomplete.
 	 */
 
+	/* Pango text bullshit */
+	layout = pango_layout_new(gdk_pango_context_get());
+	font_desc = pango_font_description_from_string("sans");
+	pango_font_description_set_size(font_desc,(8)*PANGO_SCALE);
+
 	data_handle = -1;  /* initialize to empty handle */
 	data_source = ESD;
-	comedi_window_open = TRUE;  /* open comedi control window */
 
 	scope_zoom = 1.0;	/* normal zoom, (none) */
 	refresh_rate = 34;	/* 34 frames per sec */
-	left_amplitude = 127.0/32768.0; /* Scaler for something */
-	right_amplitude = 127.0/32768.0; /* Scaler for something */
+	left_amplitude = 32768.0; /* Scaler for something */
+	right_amplitude = 32768.0; /* Scaler for something */
 	fft_signal_source = LEFT_PLUS_RIGHT;/* signal input source for fft */
 	landflip = FALSE;	/* Flip 3D axis over */
 	spikeflip = FALSE;	/* Flip 3D axis over */
@@ -214,8 +221,6 @@ void read_config(void)
 		  if(cfg_read_int(cfgfile, "Global", "data_source", &i))
 		  data_source=i;
 		}
-		cfg_read_int(cfgfile, "Global", "comedi_window_open", 
-			     &comedi_window_open);
 		cfg_read_int(cfgfile, "Global", "decimation_factor", &decimation_factor);
 		cfg_read_int(cfgfile, "Global", "fft_signal_source", &fft_signal_source);
 		cfg_read_float(cfgfile, "Global", "scope_zoom", &scope_zoom);
@@ -299,7 +304,6 @@ void save_config(GtkWidget *widget)
 		cfg_write_string(cfgfile, "Global", "last_colormap",g_strconcat(g_get_home_dir(),"/.eXtace/ColorMaps/","Default",NULL));
 	cfg_write_int(cfgfile, "Global", "mode", mode);
 	cfg_write_int(cfgfile, "Global", "data_source", data_source);
-	cfg_write_int(cfgfile, "Global", "comedi_window_open", comedi_window_open);
 	cfg_write_int(cfgfile, "Global", "decimation_factor", decimation_factor);
 	cfg_write_int(cfgfile, "Global", "fft_signal_source", fft_signal_source);
 	cfg_write_float(cfgfile, "Global", "scope_zoom", scope_zoom);
