@@ -19,6 +19,7 @@
 #include <reducer.h>
 #include <enums.h>
 #include <input.h>
+#include <stdlib.h>
 
 /* See globals.h for variable declarations and DEFINES */
 
@@ -64,7 +65,7 @@ void reducer(gfloat lowfreq, gfloat hifreq ,int axis_length)
 	/* determine the frequency spread per bin, and the low and high bin
 	 * limits for recalculating to fit the number of pips (pixels on screen)
 	 */
-	hertz_per_bin = ring_rate/(float)nsamp;
+	hertz_per_bin = ring_rate/((float)nsamp*decimation_factor);
 	lowbin = lowfreq/hertz_per_bin;
 	highbin = hifreq/hertz_per_bin;
 
